@@ -1196,7 +1196,7 @@ strptime_internal (const char *rp, const char *fmt, stm *tm,
 */
 
 attribute_hidden                				/* #nocov start */ 
-void dt_invalidate_locale() // used in platform.c
+void dt_invalidate_locale(void) // used in platform.c
 {
     locale_strings_set = 0;
     locale_w_strings_set = 0;
