@@ -1036,7 +1036,7 @@ SEXP formatPOSIXlt(SEXP argsxp, SEXP fmtsxp, SEXP tzsxp) //
 		    /* truncate to avoid nuisances such as PR#14579 */
 		    double s = secs, t = Rexp10((double) ns);
 		    s = ((int) (s*t))/t;
-		    sprintf(p2, "%0*.*f", ns+3, ns, s);
+		    snprintf(p2, sizeof(buf2), "%0*.*f", ns+3, ns, s);
 		    strcat(buf2, p+nused);
 		} else {
 		    strcat(p2, "%S");			/* #nocov */
